html

Element creation functions scraped from https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements This list automatically excludes any elements or attributes that are deprecated

Values

pub fn a(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Together with its href attribute, creates a hyperlink to web pages, files, email addresses, locations within the current page, or anything else a URL can address.

pub fn abbr(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents an abbreviation or acronym.

pub fn address(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Indicates that the enclosed HTML provides contact information for a person or people, or for an organization.

pub fn area(
  attrs: List(#(String, String)),
) -> presentable_soup.ElementTree

Defines an area inside an image map that has predefined clickable areas. An image map allows geometric areas on an image to be associated with hyperlink .

pub fn article(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents a self-contained composition in a document, page, application, or site, which is intended to be independently distributable or reusable (e.g., in syndication). Examples include a forum post, a magazine or newspaper article, a blog entry, a product card, a user-submitted comment, an interactive widget or gadget, or any other independent item of content.

pub fn aside(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents a portion of a document whose content is only indirectly related to the document’s main content. Asides are frequently presented as sidebars or call-out boxes.

pub fn audio(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Used to embed sound content in documents. It may contain one or more audio sources, represented using the src attribute or the source element: the browser will choose the most suitable one. It can also be the destination for streamed media, using a MediaStream .

pub fn b(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Used to draw the reader’s attention to the element’s contents, which are not otherwise granted special importance. This was formerly known as the Boldface element, and most browsers still draw the text in boldface. However, you should not use for styling text or granting importance. If you wish to create boldface text, you should use the CSS font-weight property. If you wish to indicate an element is of special importance, you should use the element.

pub fn base(
  attrs: List(#(String, String)),
) -> presentable_soup.ElementTree

Specifies the base URL to use for all relative URLs in a document. There can be only one such element in a document.

pub fn bdi(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Tells the browser’s bidirectional algorithm to treat the text it contains in isolation from its surrounding text. It’s particularly useful when a website dynamically inserts some text and doesn’t know the directionality of the text being inserted.

pub fn bdo(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Overrides the current directionality of text, so that the text within is rendered in a different direction.

pub fn blockquote(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Indicates that the enclosed text is an extended quotation. Usually, this is rendered visually by indentation. A URL for the source of the quotation may be given using the cite attribute, while a text representation of the source can be given using the element.

pub fn body(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents the content of an HTML document. There can be only one such element in a document.

pub fn br(
  attrs: List(#(String, String)),
) -> presentable_soup.ElementTree

Produces a line break in text (carriage-return). It is useful for writing a poem or an address, where the division of lines is significant.

pub fn button(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

An interactive element activated by a user with a mouse, keyboard, finger, voice command, or other assistive technology. Once activated, it performs an action, such as submitting a form or opening a dialog.

pub fn canvas(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Container element to use with either the canvas scripting API or the WebGL API to draw graphics and animations.

pub fn caption(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Specifies the caption (or title) of a table.

pub fn cite(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Used to mark up the title of a creative work. The reference may be in an abbreviated form according to context-appropriate conventions related to citation metadata.

pub fn code(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Displays its contents styled in a fashion intended to indicate that the text is a short fragment of computer code. By default, the content text is displayed using the user agent’s default monospace font.

pub fn col(
  attrs: List(#(String, String)),
) -> presentable_soup.ElementTree

Defines one or more columns in a column group represented by its implicit or explicit parent element. The element is only valid as a child of a element that has no span attribute defined.

pub fn colgroup(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Defines a group of columns within a table.

pub fn data(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Links a given piece of content with a machine-readable translation. If the content is time- or date-related, the

pub fn datalist(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Contains a set of

pub fn dd(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Provides the description, definition, or value for the preceding term (

) in a description list (
).

pub fn del(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents a range of text that has been deleted from a document. This can be used when rendering “track changes” or source code diff information, for example. The element can be used for the opposite purpose: to indicate text that has been added to the document.

pub fn details(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Creates a disclosure widget in which information is visible only when the widget is toggled into an “open” state. A summary or label must be provided using the

element.

pub fn dfn(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Used to indicate the term being defined within the context of a definition phrase or sentence. The ancestor

element, the

/
pairing, or the nearest section ancestor of the element, is considered to be the definition of the term.

pub fn dialog(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents a dialog box or other interactive component, such as a dismissible alert, inspector, or subwindow.

pub fn div(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

The generic container for flow content. It has no effect on the content or layout until styled in some way using CSS (e.g., styling is directly applied to it, or some kind of layout model like flexbox is applied to its parent element).

pub fn dl(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents a description list. The element encloses a list of groups of terms (specified using the

element) and descriptions (provided by
elements). Common uses for this element are to implement a glossary or to display metadata (a list of key-value pairs).

pub fn dt(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Specifies a term in a description or definition list, and as such must be used inside a

element. It is usually followed by a
element; however, multiple
elements in a row indicate several terms that are all defined by the immediate next
element.

pub fn em(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Marks text that has stress emphasis. The element can be nested, with each nesting level indicating a greater degree of emphasis.

pub fn embed(
  attrs: List(#(String, String)),
) -> presentable_soup.ElementTree

Embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser plug-in.

pub fn fencedframe(
  attrs: List(#(String, String)),
  children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree

Represents a nested browsing context, like