html
Element creation functions scraped from https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements This list automatically excludes any elements or attributes that are deprecated
Values
pub fn a(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Together with its href attribute, creates a hyperlink to web pages, files, email addresses, locations within the current page, or anything else a URL can address.
pub fn abbr(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents an abbreviation or acronym.
pub fn address(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Indicates that the enclosed HTML provides contact information for a person or people, or for an organization.
pub fn area(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Defines an area inside an image map that has predefined clickable areas. An image map allows geometric areas on an image to be associated with hyperlink .
pub fn article(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a self-contained composition in a document, page, application, or site, which is intended to be independently distributable or reusable (e.g., in syndication). Examples include a forum post, a magazine or newspaper article, a blog entry, a product card, a user-submitted comment, an interactive widget or gadget, or any other independent item of content.
pub fn aside(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a portion of a document whose content is only indirectly related to the document’s main content. Asides are frequently presented as sidebars or call-out boxes.
pub fn audio(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Used to embed sound content in documents. It may contain one or more audio sources, represented using the src attribute or the source element: the browser will choose the most suitable one. It can also be the destination for streamed media, using a MediaStream .
pub fn b(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Used to draw the reader’s attention to the element’s contents, which are not otherwise granted special importance. This was formerly known as the Boldface element, and most browsers still draw the text in boldface. However, you should not use for styling text or granting importance. If you wish to create boldface text, you should use the CSS font-weight property. If you wish to indicate an element is of special importance, you should use the element.
pub fn base(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Specifies the base URL to use for all relative URLs in a document. There can be only one such element in a document.
pub fn bdi(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Tells the browser’s bidirectional algorithm to treat the text it contains in isolation from its surrounding text. It’s particularly useful when a website dynamically inserts some text and doesn’t know the directionality of the text being inserted.
pub fn bdo(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Overrides the current directionality of text, so that the text within is rendered in a different direction.
pub fn blockquote(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Indicates that the enclosed text is an extended quotation. Usually, this is rendered visually by indentation. A URL for the source of the quotation may be given using the cite attribute, while a text representation of the source can be given using the element.
pub fn body(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents the content of an HTML document. There can be only one such element in a document.
pub fn br(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Produces a line break in text (carriage-return). It is useful for writing a poem or an address, where the division of lines is significant.
pub fn button(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
An interactive element activated by a user with a mouse, keyboard, finger, voice command, or other assistive technology. Once activated, it performs an action, such as submitting a form or opening a dialog.
pub fn canvas(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Container element to use with either the canvas scripting API or the WebGL API to draw graphics and animations.
pub fn caption(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Specifies the caption (or title) of a table.
pub fn cite(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Used to mark up the title of a creative work. The reference may be in an abbreviated form according to context-appropriate conventions related to citation metadata.
pub fn code(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Displays its contents styled in a fashion intended to indicate that the text is a short fragment of computer code. By default, the content text is displayed using the user agent’s default monospace font.
pub fn col(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Defines one or more columns in a column group represented by its implicit or explicit parent
pub fn colgroup(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Defines a group of columns within a table.
pub fn data(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Links a given piece of content with a machine-readable translation. If the content is time- or date-related, the
pub fn datalist(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Contains a set of
pub fn dd(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Provides the description, definition, or value for the preceding term (
- ).
pub fn del(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a range of text that has been deleted from a document. This can be used when rendering “track changes” or source code diff information, for example. The element can be used for the opposite purpose: to indicate text that has been added to the document.
pub fn details(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Creates a disclosure widget in which information is visible only when the widget is toggled into an “open” state. A summary or label must be provided using the
pub fn dfn(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Used to indicate the term being defined within the context of a definition phrase or sentence. The ancestor
element, the
pub fn dialog(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a dialog box or other interactive component, such as a dismissible alert, inspector, or subwindow.
pub fn div(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
The generic container for flow content. It has no effect on the content or layout until styled in some way using CSS (e.g., styling is directly applied to it, or some kind of layout model like flexbox is applied to its parent element).
pub fn dl(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a description list. The element encloses a list of groups of terms (specified using the
pub fn dt(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Specifies a term in a description or definition list, and as such must be used inside a
- element. It is usually followed by a
- element; however, multiple
- elements in a row indicate several terms that are all defined by the immediate next
- element.
pub fn em(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Marks text that has stress emphasis. The element can be nested, with each nesting level indicating a greater degree of emphasis.
pub fn embed(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser plug-in.
pub fn fencedframe(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a nested browsing context, like
pub fn fieldset(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Used to group several controls as well as labels (
pub fn figcaption(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a caption or legend describing the rest of the contents of its parent
pub fn figure(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents self-contained content, potentially with an optional caption, which is specified using the
pub fn footer(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a footer for its nearest ancestor sectioning content or sectioning root element. A
pub fn form(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a document section containing interactive controls for submitting information.
pub fn geolocation(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Creates an interactive control for the user to share their geolocation data with the page.
pub fn h1(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represent six levels of section headings.
is the highest section level and is the lowest.
pub fn h2(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represent six levels of section headings.
is the highest section level and is the lowest.
pub fn h3(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represent six levels of section headings.
is the highest section level and is the lowest.
pub fn h4(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represent six levels of section headings.
is the highest section level and is the lowest.
pub fn h5(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represent six levels of section headings.
is the highest section level and is the lowest.
pub fn h6(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represent six levels of section headings.
is the highest section level and is the lowest.
pub fn head(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Contains machine-readable information (metadata) about the document, like its title , scripts , and style sheets .
pub fn header(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents introductory content, typically a group of introductory or navigational aids. It may contain some heading elements but also a logo, a search form, an author name, and other elements.
pub fn hgroup(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a heading grouped with any secondary content, such as subheadings, an alternative title, or a tagline.
pub fn hr(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Represents a thematic break between paragraph-level elements: for example, a change of scene in a story, or a shift of topic within a section.
pub fn html(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents the root (top-level element) of an HTML document, so it is also referred to as the root element . All other elements must be descendants of this element.
pub fn i(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a range of text that is set off from the normal text for some reason, such as idiomatic text, technical terms, and taxonomical designations, among others. Historically, these have been presented using italicized type, which is the original source of the naming of this element.
pub fn iframe(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a nested browsing context, embedding another HTML page into the current one.
pub fn img(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Embeds an image into the document.
pub fn input(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Used to create interactive controls for web-based forms to accept data from the user; a wide variety of types of input data and control widgets are available, depending on the device and user agent. The element is one of the most powerful and complex in all of HTML due to the sheer number of combinations of input types and attributes.
pub fn ins(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a range of text that has been added to a document. You can use the element to similarly represent a range of text that has been deleted from the document.
pub fn kbd(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a span of inline text denoting textual user input from a keyboard, voice input, or any other text entry device. By convention, the user agent defaults to rendering the contents of a element using its default monospace font, although this is not mandated by the HTML standard.
pub fn label(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a caption for an item in a user interface.
pub fn legend(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents a caption for the content of its parent
pub fn li(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents an item in a list. It must be contained in a parent element: an ordered list (
- ), an unordered list (
- ), or a menu (
pub fn link(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Specifies relationships between the current document and an external resource. This element is most commonly used to link to CSS but is also used to establish site icons (both “favicon” style icons and icons for the home screen and apps on mobile devices) among other things.
pub fn main(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents the dominant content of the body of a document. The main content area consists of content that is directly related to or expands upon the central topic of a document, or the central functionality of an application.
pub fn map(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Used with elements to define an image map (a clickable link area).
pub fn mark(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
Represents text which is marked or highlighted for reference or notation purposes due to the marked passage’s relevance in the enclosing context.
pub fn math(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
The top-level element in MathML. Every valid MathML instance must be wrapped in it. In addition, you must not nest a second
pub fn menu(
attrs: List(#(String, String)),
children: List(presentable_soup.ElementTree),
) -> presentable_soup.ElementTree
A semantic alternative to
- , but treated by browsers (and exposed through the accessibility tree) as no different than
- elements).
- . It represents an unordered list of items (which are represented by
pub fn meta(
attrs: List(#(String, String)),
) -> presentable_soup.ElementTree
Represents metadata that cannot be represented by other HTML meta-related elements, like